# WebWatcher

A simple tool to watch for changes in a web page. Good for:

 1. Waiting for job postings to change or appear
 2. New content for blogs or personal sites that don't have email / rss / atom feeds

## Licenses

This code is licensed under the MPL 2.0 [LICENSE](LICENSE).

